PyXMake Developer Guide: PyXMake.VTL.stm_make.pyx_f2py Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Public Member Functions | Public Attributes | Static Public Attributes | List of all members
PyXMake.VTL.stm_make.pyx_f2py Class Reference
Inheritance diagram for PyXMake.VTL.stm_make.pyx_f2py:

## Public Member Functions
def | initialize_options (self)
def | finalize_options (self)
Public Member Functions inherited from PyXMake.VTL.stm_make._BaseCommandRunner
def | run (self)

## Public Attributes
| verbose
| source_path
| output_file_path
| base_path
| scratch_path
| libs
| includes
| libpaths
| incremental
| msvsc

## Static Public Attributes
string | description = "Runs the build process of Fortran source code for Python using f2py."
list | user_options

## Detailed Description

    Base class for encapsulating command line arguments and build process.

Definition at line 498 of file stm_make.py.

## Member Function Documentation

## ◆ finalize_options()

def PyXMake.VTL.stm_make.pyx_f2py.finalize_options | ( |  | self | ) |

    Post-process options.

Definition at line 540 of file stm_make.py.

## ◆ initialize_options()

def PyXMake.VTL.stm_make.pyx_f2py.initialize_options | ( |  | self | ) |

    Set default values for options.

Definition at line 516 of file stm_make.py.

## Member Data Documentation

## ◆ user_options

list PyXMake.VTL.stm_make.pyx_f2py.user_options
| static

Initial value:
= [
# The format is (long option, short option, description).
('msvsc=', None, 'identifier, which compiler version from Microsoft Visual Studio to be used'),
('source-path=', None, 'path to the folder holding the fortran files'),
('verbose=', None, 'controls the logging level (0 - Nothing) Default: 2 - Everything'),
('scratch-path=', None, 'path to scratch folder where all temporary data is located during the build event'),
('output-file-path=', None, 'path to the output directory'),
('base-path=', None, 'path to base folder - optional'),
]

Definition at line 506 of file stm_make.py.

The documentation for this class was generated from the following file:

- D:/03_Workspaces/01_Eclipse/pyx_core/PyXMake/VTL/stm_make.py